#!/usr/bin/python3
# -*- coding: utf-8 -*-
# Python script to ceate the drop.xml for firewalld from an arbitrary set of
# IP addresses to be blocked
#
# Usage: drop.py blocklist1.txt blocklist2.txt ...


import sys


def readfile(filename):
    ret = []
    with open(filename, "r") as f_in:
        for line in f_in.readlines():
            line = line.strip()
            # Ignore empty and comment lines
            if line == "" or line[0] in "#;!.":
                continue
            ret.append(line)
    return ret


if __name__ == "__main__":
    # Empty parameter prints usage
    if len(sys.argv) < 2 or sys.argv[1] == "-h" or sys.argv[1] == "--help":
        print("Usage: %s blocklist1 blocklist2 .... " % (sys.argv[0]))
        print(
            "  Blocklist are plain text files with IP address ranges (IPv4 or IPv6 CIDR) that need to be blocked"
        )
        print("\nerror: No blocklist given")
        sys.exit(1)

    # Print the XML footer for the zone
    print(
        '<?xml version="1.0" encoding="utf-8"?>\n<zone target="DROP">\n  <short>Drop</short>\n  <description>Unsolicited incoming network packets are dropped. Incoming packets that are related to outgoing network connections are accepted. Outgoing network connections are allowed.</description>'
    )

    # Iterate over input files and print for each of the read address the corresponding block line
    for filename in sys.argv[1:]:
        for addr in readfile(filename):
            print('  <source address="%s"/>' % (addr))
    # XML header
    print("</zone>")
